﻿/**
 * \file DontDestroyOnLoadScene.cs
 * \brief Permet de conserver des objets entre plusieurs scènes
 * 
 * \version 1.0
 * \author Thibault CLAUSS
 */

using UnityEngine;
using UnityEngine.SceneManagement;
public class DontDestroyOnLoadScene : MonoBehaviour
{
    /**Tableau des éléments conserver entre les scènes.*/
    public GameObject[] objet;

    public static DontDestroyOnLoadScene instance;

    /**
     * Méthode propre a Unity qui se lance à chaque début de scène/niveau ou se script est utilisé. \n
     * Ici elle est utilisé pour ne pas détruire les éléments du tableau objet au lancement du scène.
     */
    void Awake()
    {
        if(instance != null)
        {
            Debug.LogWarning("Il n'y a plus d'instance de DontDestroOnLoad dans la scène");
            return;
        }

        instance = this;

        foreach(var element in objet)
        {
            DontDestroyOnLoad(element);
        }

        int sceneID = SceneManager.GetActiveScene().buildIndex;
        if (sceneID == 2)
        {
            RemoveFromDontDestroyOnLoad();
            Destroy(GameObject.Find("Player"));
            Destroy(GameObject.Find("Audio Source"));

        }
    }

    /**Méthode permettant de supprimer les éléments du tableaux objet en les déplaçant dans la scène active.*/
    public void RemoveFromDontDestroyOnLoad()
    {
        foreach(var element in objet)
        {
            SceneManager.MoveGameObjectToScene(element, SceneManager.GetActiveScene());
        }
    }
}
